@@ -31,5 +31,5 @@ if not src.configureoutput.WITH_GNOME:
 
 import src.i18n
 src.i18n.initialise("share/locale")
-import src.startup
+import src.mainwin
 
