@@ -187,49 +187,4 @@ code to handle situations like this.)"""
         if soundcard.synth:
             soundcard.synth.close()
 
-def do_some_cmdline_options(argv):
-        if filter(lambda a, argv=argv: a in argv, ['-h', '--help']):
-            print """
-GNU Solfege %s
-Type "man solfege" for more details.
-Options:
-  --no-sound             Do not play any sounds. Useful when porting.
-  --verbose-sound-init   display more info about the sound setup
-  -v, --version
-  -w, --warranty         show warranty and copyright
-  -h, --help             Display this message
-  --gtk-help             Display the usual gtk/gnome commandline options.
-    """ % configureoutput.VERSION_STRING
-            sys.exit()
-
-        if filter(lambda a, argv=argv: a in argv, ['-v', '--version']):
-            print """GNU Solfege %s
-This is free software. It is covered by the GNU General Public License,
-and you are welcome to change it and/or distribute copies of it under
-certain conditions. Invoke as `solfege --warranty` for more information.
-
-Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
-            """ % configureoutput.VERSION_STRING
-            sys.exit()
-
-        if filter(lambda a, argv=argv: a in argv, ['-w', '--warranty']):
-            print """GNU Solfege %s
-Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
-
-    This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License version 2
-as published by the Free Software Foundation.
-
-    This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-General Public License for more details.
-
-    You should have received a copy (refer to the file COPYING) of the
-GNU General Public License along with this program; if not, write to
-the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
-USA.
-        """ % configureoutput.VERSION_STRING
-            sys.exit()
-
 
