@@ -18,7 +18,7 @@
 import gtk, gnome
 import abstract, idbyname, const, mpd, gu, statisticsviewer, widgets
 from i18n import _
-import soundcard, mpd
+import soundcard, mpd, mpd.musicdisplayer
 
 class Teacher(idbyname.Teacher):
     def __init__(self, exname, app):
@@ -47,7 +47,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.set_usize(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
         
