@@ -93,7 +93,7 @@ class LessonfileCommon:
         """
         if self.header.musicformat == 'chord':
             return r"\staff\transpose %s{< %s > }" \
-              % (self.m_transpose.notename(), self.m_questions[self._idx]['music'])
+              % (self.m_transpose.str(), self.m_questions[self._idx]['music'])
         s = self.m_questions[self._idx]['music']
         if self.header.random_transpose:
             s = string.replace(s, r'\staff',
