@@ -172,3 +172,6 @@ def parse_key_string(string):
     else:
         return mod, GDK.__dict__[s]
 
+def exercise_name_to_module_name(name):
+    # it is just plain luck that this works...
+    return string.replace(name, '-', '')
